@@ -79,15 +79,15 @@ def parse_to_python_object(string):
     unquoted_regex = re.compile(r"^([\w.@#-]+)(.*)", re.DOTALL)
 
     def parse_string(src):
-        match = unquoted_regex.match(src)
-        if match is not None:
-            string, src = match.groups()
-            yield string, src.strip()
-            
         match = quoted_regex.match(src)
         if match is not None:
             string, src = match.groups()
-            yield string, src.strip()
+            yield string, src.lstrip()
+            
+        match = unquoted_regex.match(src)
+        if match is not None:
+            string, src = match.groups()
+            yield string, src.lstrip()      
 
     def parse_word(word, value=None):
         l = len(word)
@@ -176,29 +176,21 @@ def parse_to_python_object(string):
             parse_semicolomn,
             )(src):
             yield {key: value}, src
-
-    #upgd
-    #for (value, _, values), src in sequence(
-        #parse_value,
-        #parse_comma,
-        #parse_comma_separated_values
-        #)(src):
-        #yield [value] + values, src
-        #return
-
-    #for value, src in parse_value(src):
-        #yield [value], src    
+ 
     def parse_semicolomn_separated_keyvalues(src):
-        for (keyvalue, keyvalues), src in sequence(
-            parse_keyvalue,
-            parse_semicolomn_separated_keyvalues,
-            )(src):
-            keyvalue.update(keyvalues)
-            yield keyvalue, src
+        result = {}
+        for value, src in parse_keyvalue(src):
+            result.update(value)
+            break
+        else:
             return
-
-        for keyvalue, src in parse_keyvalue(src):
-            yield keyvalue, src
+        while src:
+            for (value), src in parse_keyvalue(src):
+                result.update(value)
+                break
+            else:
+                break
+        yield result, src
 
     string = string.replace('\n', '')
 
